Learn R Programming

mixcat (version 1.0-2)

summary.npmreg: Summarizing mixed multinomial regression model fits

Description

summary and print methods for objects of type npmreg.

Usage

## S3 method for class 'npmreg':
summary(object,digits = max(3, getOption("digits") - 3),...)
## S3 method for class 'npmreg':
print(x,digits = max(3, getOption("digits") - 3),...)

Arguments

object
an object of class npmreg.
x
an object of class npmreg.
digits
the minimum number of significant digits to be printed in values.
...
further arguments, which will mostly be ignored.

Value

  • Summary or print.

Details

The function npmlt returns an object of class "npmreg". The function summary (i.e., summary.npmreg) can be used to obtain or print a summary of the results, and the function print (i.e., print.npmreg) to print the results.

See Also

npmlt

Examples

Run this code
data(schizo)
attach(schizo)
fit1<-npmlt(y~trt*sqrt(wk),formula.npo=~trt,random=~1,id=id,k=2)
print(fit1)
summary(fit1)

Run the code above in your browser using DataLab