mixcat-package: Mixed effects cumulative link and logistic regression models
Description
Mixed effects models for the analysis of binary or
multinomial (ordinal or nominal) data with non-parametric
distribution for the random effects.
The main function is npmlt and it fits
cumulative and baseline logit models.Acknowledgments
Papageorgiou's work was supported by the Science Foundation Ireland Research Frontiers grant 07/RFP/MATF448.Details
ll{
Package: mixcat
Type: Package
Version: 1.0-0
Date: 2011-09-11
License: GPL (>=2)
LazyLoad: no
}
This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.
For details on the GNU General Public License
see http://www.gnu.org/copyleft/gpl.html or
write to the Free Software Foundation, Inc., 51 Franklin Street,
Fifth Floor, Boston, MA 02110-1301, USA.References
Papageorgiou, G. and Hinde, J. (2012).
Multivariate generalized linear mixed models with semi-nonparametric and smooth
nonparametric random effects densities. Statistics and Computing 22, 79-92